Closes #XX

## Changes

> Description of changes in this PR.
> Use `make changelog` for starter.
> Should be copied and commit to `CHANGELOG.md`

#### Breaking changes

#### Features

#### Fixes

#### Internals

## Tests

- [ ] QC test passes locally (`make test`)
- [ ] CI tests pass

## Reviewer

> Select @ reviewer
